--  ___FILENAME___
--  ___PACKAGENAME___

--  Created by ___FULLUSERNAME___ on ___DATE___.
--___COPYRIGHT___

script ___PACKAGENAMEASIDENTIFIER___
	
	## The language used in this template is AppleScriptObj-C, a powerful fusion of the AppleScript and Objective-C languages.
	
	## Apple TN2322: Building a Cocoa-AppleScript (AppleScriptObjC) Automator Action: https://developer.apple.com/library/mac/technotes/tn2322/_index.html
	
	## Automator action build settings info: https://developer.apple.com/library/mac/qa/qa1885/_index.html
	## -action "$(BUILT_PRODUCTS_DIR)/$(FULL_PRODUCT_NAME)"
	
	## To aquire comprehensive documetation and examples of AppleScriptObj-C, visit: https://macosxautomation.com/applescript/apps
	
	## https://configautomation.com
	
	property parent : class "AMBundleAction"
	
	-- Properties for controlling logging in Console
	property loggingStatus : true
	
	(* OUTLET PROPERTIES *)
	## properties used as outlets represent UI controls and have default values of: missing value
	## use the Files Owner connection palatte in the xib to drag connection from this property to the control
	## For example, an outlet property for a text field (remember to remove this property if not used in your project):
	property textInputField : missing value
	
	(* The title of the action for logging *)
	property actionDisplayName : "___PACKAGENAME___"
	
	
	on runWithInput:input fromAction:anAction |error|:errorRef
		try
			my logThis("runWithInput()")
			
			## IF THIS ACTION EXPECTS A LIST OF DEVICE ECIDs AS ITS INPUT, INCLUDE THIS ROUTINE:
			set theseECIDs to input as list
			if theseECIDs is {} then
				error (my getLocalizedStringForKey("NO_INPUT_ERROR"))
			end if
			
			## GET THE CURRENT PARAMETER SETTINGS FROM THE ACTION UI
			
			## NOTE: When buidling your actions, enter parameter names in two locations in the action project:
			## 1) in the AMDefaultParameters element in the Info.plist, and
			## 2) in the list of object controller keys for the Parameters object in the main.xib file
			
			## STORE THE ACTION PARAMETERS DICTIONARY IN A VARIABLE
			set the parametersDictionary to my parameters()
			
			## GET AND LOG THE VALUES OF THE ACTION VIEW CONTROLS FROM THE PARAMETERS DICTIONARY
			-- NOTE: be sure to always coerce the values in AppleScript values. EX: as string, as integer, as boolean, etc.
			
			set textFieldInput to ((parametersDictionary's valueForKey:"textFieldInput") as string)
			my logThis("textFieldInput: " & textFieldInput)
			
			(*
			set popupMenuIndex to ((parametersDictionary's valueForKey:"popupMenuIndex") as integer)
			my logThis("popupMenuIndex: " & popupMenuIndex)
			
			set checkBoxState to ((parametersDictionary's valueForKey:"checkBoxState") as boolean)
			my logThis("checkBoxState: " & checkBoxState)
			*)
			
			
			## PROCESSING STATEMENTS GO HERE
			
			
			## HOW TO CALL A HANDLER IN THE CONFIGURATION UTILITY LIBRARY
			tell script "Configuration Utility"
				show help -- view the complete list of library handlers with descriptions and examples
				## CNFGbackupSpecifiedDevices(theseECIDs) -- calling a script library handler
			end tell
			
			
			
			## ALWAYS PASS A LIST OF THE DEVICE ECIDS TO THE NEXT ACTION, UNLESS THE AMProvides ELEMENT IN THE INFO.PLIST IS SET FOR com.apple.cocoa.path, IN WHICH CASE YOU PASS FILE REFERENCES
			return theseECIDs
			
		on error errorMessageString number errorNumber
			## THIS ERROR HANDLER WILL LOG THE ERROR AND STOP THE WORKFLOW
			my logThis(errorMessageString)
			if errorNumber is not -128 then
				set contents of errorRef to {NSAppleScriptErrorNumber:errorNumber, NSAppleScriptErrorMessage:errorMessageString}
				return missing value
			else
				set contents of errorRef to {NSAppleScriptErrorNumber:-128}
				return missing value
			end if
		end try
	end runWithInput:fromAction:|error|:
	
	(* HANDLER CALLED BEFORE ACTION VIEW APPEARS IN WORKFLOW *)
	on opened()
		my logThis("opened()")
		
	end opened
	
	(* HANDLER CALLED TO STORE THE CURRENT SELECTIONS. CALLED WHEN WORKFLOW IS SAVED OR RUN *)
	on updateParameters()
		my logThis("updateParameters()")
		
	end updateParameters
	
	(* HANDLER FOR UI INTERACTION (remove if not used in your project) *)
	on displayContentsOfTextField:sender
		set buttonTitle to (sender's title()) as string
		set textContent to (textInputField's stringValue()) as string
		set dialogMessage to "You pressed the button named " & buttonTitle & " to show the text fields contents:" & linefeed & linefeed & textContent
		display dialog dialogMessage buttons {"OK"} default button 1
	end displayContentsOfTextField:
	
	(* SUPPORT HANDLERS *)
	
	(* LOGGING HANDLER *)
	on logThis(itemToLog)
		if loggingStatus is true then
			tell current application
				if class of itemToLog is list then
					set itemCount to the count of itemToLog
					repeat with i from 1 to the itemCount
						log ("ACTION: " & actionDisplayName & ": " & (i as string) & ":" & (itemCount as string) & space & (item i of itemToLog))
					end repeat
				else
					log ("ACTION: " & actionDisplayName & ": " & itemToLog)
				end if
			end tell
		end if
	end logThis
	
	(* LOCALIZATION HANDLER *)
	on getLocalizedStringForKey(key)
		return my (bundle()'s localizedStringForKey:key value:(missing value) table:(missing value)) as string
	end getLocalizedStringForKey
	
end script
